@@ -4,6 +4,7 @@ import logging
 import hashlib
 from io import BufferedReader
 from typing import List, Optional  # pylint:disable=unused-import
+import typing
 
 import sortedcontainers
 
@@ -17,7 +18,6 @@ from ..errors import CLEOperationError, CLEError
 
 l = logging.getLogger(name=__name__)
 
-import typing
 
 if typing.TYPE_CHECKING:
     from .. import Loader
@@ -173,7 +173,7 @@ class Backend:
         self.relocs = []
         self.irelatives = []    # list of tuples (resolver, destination), dest w/o rebase
         self.jmprel = {}
-        self.arch = None
+        self.arch = None # type: Optional[archinfo.Arch]
         self.os = None  # Let other stuff override this
         self.compiler = None, None  # compiler name, version
         self._symbol_cache = {}
